<?php
namespace Delo;

use \Registry;

class DeloDebugInfo
{
    static protected $instance = null;
    /** @var array */
    private $info = [];

    /**
     * Метод для доступа к одному и тому экземпляру класса
     * @aram Registry $registry
     * @return DeloDebugInfo
     */
    static public function getInstance($registry)
    {
        if (null === static::$instance) {
            $className = get_called_class();
            static::$instance = new $className($registry);
        }
        return static::$instance;
    }

    /**
     * @param Registry $registry
     */
    public function __construct($registry)
    {
        // Он вроде и не нужен, но все библиотеки должны на вход конструктора принимать Registry
    }

    /**
     * Запоминает сообщение
     * @param string $message
     * @return int id
     */
    public function set($message)
    {
        $c = array_push($this->info, $message);
        return $c - 1;
    }

    /**
     * Добавляет в конец сообщения - ok
     * @param int $messageId id сообщения
     * @param string $additionMessage добавочное сообщение
     */
    public function setOk($messageId, $additionMessage = 'ok')
    {
        if (!empty($this->info[$messageId])) {
            $this->info[$messageId] .= $additionMessage;
        }
    }

    /**
     * Возвращает собранную информацию обрамленную в кусок xml
     * @return string
     */
    public function getXml()
    {
        if (empty($this->info)) {
            return '';
        }
        $out = "<debug>\n";
        foreach ($this->info as $info) {
            $out .= '<info><![CDATA[' . $info . "]]></info>\n";
        }
        $out .= "</debug>\n";
        return $out;
    }
}
